@@ -22,15 +22,15 @@ class ConfigureDialog : public KConfigDialog
   public:
     explicit ConfigureDialog(  QWidget *parent = nullptr
                              , KitenConfigSkeleton *config = nullptr );
-    virtual ~ConfigureDialog();
+    ~ConfigureDialog() override;
 
-  signals:
+  Q_SIGNALS:
     void settingsChangedSignal();
     void updateWidgetsSignal();
     void updateWidgetsDefaultSignal();
     void updateSettingsSignal();
 
-  private slots:
+  private Q_SLOTS:
     void updateConfiguration();
     void updateSettings() override;
     void updateWidgets() override;
