@@ -12,7 +12,6 @@
 
 #include "ui_radselectprefdialog.h"
 
-#include <kxmlgui_version.h>
 #include <KActionCollection>
 #include <KConfig>
 #include <KConfigDialog>
@@ -41,11 +40,7 @@ RadSelect::RadSelect()
   KStandardAction::quit( this, SLOT(close()), actionCollection() );
   KStandardAction::preferences( this, SLOT(optionsPreferences()), actionCollection() );
 
-#if KXMLGUI_VERSION >= QT_VERSION_CHECK(5, 84, 0)
   KStandardAction::keyBindings(guiFactory(), &KXMLGUIFactory::showConfigureShortcutsDialog, actionCollection());
-#else
-  KStandardAction::keyBindings( (const QObject*)guiFactory(), SLOT(configureShortcuts()), actionCollection() );
-#endif
 
   statusBar()->show();
 
